/*
 * Copyright (C) 2007 The Android Open Source Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.example.android.bigwall;

import android.app.Activity;
import android.os.Bundle;
import android.view.Menu;
import android.view.MenuItem;
import android.widget.TextView;

import com.example.android.bigwall.BigWallGameView.BigWallGameThread;

/**
 * This is a simple BigWallGame activity that houses a single BigWallGameView. It
 * demonstrates...
 * <ul>
 * <li>animating by calling invalidate() from draw()
 * <li>loading and drawing resources
 * <li>handling onPause() in an animation
 * </ul>
 */
public class BigWallGame extends Activity {

    private static final int MENU_PAUSE = 1;
    private static final int MENU_RESUME = 2;
    private static final int MENU_START = 3;
    private static final int MENU_STOP = 4;

    /** A handle to the thread that's actually running the animation. */
    private BigWallGameThread mBigWallGameThread;

    /** A handle to the View in which the game is running. */
    private BigWallGameView mBigWallGameView;

    /**
     * Invoked during init to give the Activity a chance to set up its Menu.
     *
     * @param menu the Menu to which entries may be added
     * @return true
     */
    @Override
    public boolean onCreateOptionsMenu(Menu menu) {
        super.onCreateOptionsMenu(menu);

        menu.add(0, MENU_START, 0, R.string.menu_start);
        menu.add(0, MENU_STOP, 0, R.string.menu_stop);
        menu.add(0, MENU_PAUSE, 0, R.string.menu_pause);
        menu.add(0, MENU_RESUME, 0, R.string.menu_resume);

        return true;
    }

    /**
     * Invoked when the user selects an item from the Menu.
     *
     * @param item the Menu entry which was selected
     * @return true if the Menu item was legit (and we consumed it), false
     *         otherwise
     */
    @Override
    public boolean onOptionsItemSelected(MenuItem item) {
        switch (item.getItemId()) {
            case MENU_START:
                mBigWallGameThread.doStart();
                return true;
            case MENU_STOP:
                mBigWallGameThread.setState(BigWallGameThread.STATE_LOSE,
                        getText(R.string.message_stopped));
                return true;
            case MENU_PAUSE:
                mBigWallGameThread.pause();
                return true;
            case MENU_RESUME:
                mBigWallGameThread.unpause();
                return true;
//            case MENU_EASY:
 //               mBigWallGameThread.setDifficulty(BigWallGameThread.DIFFICULTY_EASY);
 //               return true;
        }

        return false;
    }

    /**
     * Invoked when the Activity is created.
     *
     * @param savedInstanceState a Bundle containing state saved from a previous
     *        execution, or null if this is a new execution
     */
    @Override
    protected void onCreate(Bundle savedInstanceState) {
       // super.onCreate(savedInstanceState);
    	super.onCreate(null);
    	
        // tell system to use the layout defined in our XML file
        setContentView(R.layout.bigwallgame);

        // get handles to the BigWallGameView from XML, and its BigWallGameThread
        mBigWallGameView = (BigWallGameView) findViewById(R.id.bigwallgameview);
        mBigWallGameThread = mBigWallGameView.getThread();

        // give the BigWallGameView a handle to the TextView used for messages
        mBigWallGameView.setTextView((TextView) findViewById(R.id.text));

            // we were just launched: set up a new game
            mBigWallGameThread.setState(BigWallGameThread.STATE_READY);
 
    }

    /**
     * Invoked when the Activity loses user focus.
     */
    
    @Override
    protected void onPause() {
    	
        super.onPause();
      //  mBigWallGameView.getThread().pause(); // pause game when Activity pauses
        
    	finish();   // just die...
    }

}
